@@ -27,7 +27,7 @@ class TrtcClient(AbstractClient):
 
 
     def CreatePicture(self, request):
-        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+        """如果您需要在 [云端混流转码](https://cloud.tencent.com/document/product/647/16827) 时频繁新增自定义背景图或水印，可通过此接口上传新的图片素材。无需频繁新增图片的场景，建议直接在 [控制台 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769) 中操作。
 
         :param request: Request instance for CreatePicture.
         :type request: :class:`tencentcloud.trtc.v20190722.models.CreatePictureRequest`
@@ -36,7 +36,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePicture", params)
+            headers = request.headers
+            body = self.call("CreatePicture", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePictureResponse()
@@ -64,7 +65,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTroubleInfo", params)
+            headers = request.headers
+            body = self.call("CreateTroubleInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTroubleInfoResponse()
@@ -83,7 +85,7 @@ class TrtcClient(AbstractClient):
 
 
     def DeletePicture(self, request):
-        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+        """如果您需要在 [云端混流转码](https://cloud.tencent.com/document/product/647/16827) 时频繁删除自定义背景图或水印，可通过此接口删除已上传的图片。无需频繁删除图片的场景，建议直接在 [控制台 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769) 中操作。
 
         :param request: Request instance for DeletePicture.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DeletePictureRequest`
@@ -92,7 +94,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePicture", params)
+            headers = request.headers
+            body = self.call("DeletePicture", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePictureResponse()
@@ -120,7 +123,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAbnormalEvent", params)
+            headers = request.headers
+            body = self.call("DescribeAbnormalEvent", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAbnormalEventResponse()
@@ -139,8 +143,8 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeCallDetail(self, request):
-        """查询指定时间内的用户列表及用户通话质量数据，可查询14天内数据。DataType 不为null，查询实时数据时，查询起止时间不超过1个小时，每次查询用户不超过6个，支持跨天查询。DataType，UserIds为null时，默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        """查询指定时间内的用户列表及用户通话质量数据，可查询14天内数据。DataType 不为null，查询起止时间不超过1个小时，查询用户不超过6个，支持跨天查询。DataType，UserIds为null时，查询起止时间不超过4个小时， 默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeCallDetail.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeCallDetailRequest`
@@ -149,7 +153,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCallDetail", params)
+            headers = request.headers
+            body = self.call("DescribeCallDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCallDetailResponse()
@@ -177,7 +182,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDetailEvent", params)
+            headers = request.headers
+            body = self.call("DescribeDetailEvent", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDetailEventResponse()
@@ -195,6 +201,35 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeExternalTrtcMeasure(self, request):
+        """获取Trtc的用量统计数据。走计费渠道二期 只允许查两天的数据
+
+        :param request: Request instance for DescribeExternalTrtcMeasure.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeExternalTrtcMeasureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeExternalTrtcMeasureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeExternalTrtcMeasure", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeExternalTrtcMeasureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeHistoryScale(self, request):
         """可查询sdkqppid 每天的房间数和用户数，每分钟1次，可查询最近14天的数据。当天未结束，无法查到当天的房间数与用户数。
 
@@ -205,7 +240,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeHistoryScale", params)
+            headers = request.headers
+            body = self.call("DescribeHistoryScale", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeHistoryScaleResponse()
@@ -224,7 +260,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribePicture(self, request):
-        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+        """如果您需要在 [云端混流转码](https://cloud.tencent.com/document/product/647/16827) 时频繁查找自定义背景图或水印信息，可通过此接口查找已上传的图片信息。无需频繁查找图片信息的场景，建议直接在 [控制台 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769) 中查看。
 
         :param request: Request instance for DescribePicture.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribePictureRequest`
@@ -233,7 +269,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePicture", params)
+            headers = request.headers
+            body = self.call("DescribePicture", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePictureResponse()
@@ -251,90 +288,6 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeRealtimeNetwork(self, request):
-        """查询sdkappid维度下每分钟实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeNetwork.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeNetwork", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeNetworkResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRealtimeQuality(self, request):
-        """查询sdkappid维度下每分钟实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeQuality.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeQuality", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeQualityResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRealtimeScale(self, request):
-        """查询sdkappid维度下每分钟实时规模，可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
-
-        :param request: Request instance for DescribeRealtimeScale.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRealtimeScale", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRealtimeScaleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeRecordStatistic(self, request):
         """查询云端录制计费时长。
 
@@ -350,7 +303,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecordStatistic", params)
+            headers = request.headers
+            body = self.call("DescribeRecordStatistic", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordStatisticResponse()
@@ -370,7 +324,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeRoomInformation(self, request):
         """查询sdkappid下的房间列表。默认返回10条通话，一次最多返回100条通话。可查询14天内的数据。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeRoomInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRoomInformationRequest`
@@ -379,7 +333,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRoomInformation", params)
+            headers = request.headers
+            body = self.call("DescribeRoomInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRoomInformationResponse()
@@ -397,38 +352,6 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeTrtcInteractiveTime(self, request):
-        """查询音视频互动计费时长。
-        - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
-        - 单次查询统计区间最多不能超过31天。
-        - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
-        - 日结后付费将于次日上午推送账单，建议次日上午9点以后再来查询前一天的用量。
-
-        :param request: Request instance for DescribeTrtcInteractiveTime.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeTrtcInteractiveTime", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeTrtcInteractiveTimeResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeTrtcMcuTranscodeTime(self, request):
         """查询旁路转码计费时长。
         - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
@@ -443,7 +366,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTrtcMcuTranscodeTime", params)
+            headers = request.headers
+            body = self.call("DescribeTrtcMcuTranscodeTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTrtcMcuTranscodeTimeResponse()
@@ -463,7 +387,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeUserInformation(self, request):
         """查询指定时间内的用户列表，可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
-        注意：不建议依赖接口做实时类业务逻辑处理
+        **注意**：该接口只用于历史数据统计或核对数据使用，实时类关键业务逻辑不能使用。
 
         :param request: Request instance for DescribeUserInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeUserInformationRequest`
@@ -472,7 +396,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUserInformation", params)
+            headers = request.headers
+            body = self.call("DescribeUserInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserInformationResponse()
@@ -500,7 +425,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DismissRoom", params)
+            headers = request.headers
+            body = self.call("DismissRoom", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DismissRoomResponse()
@@ -528,7 +454,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DismissRoomByStrRoomId", params)
+            headers = request.headers
+            body = self.call("DismissRoomByStrRoomId", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DismissRoomByStrRoomIdResponse()
@@ -547,7 +474,7 @@ class TrtcClient(AbstractClient):
 
 
     def ModifyPicture(self, request):
-        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+        """如果您需要在 [云端混流转码](https://cloud.tencent.com/document/product/647/16827) 时频繁修改自定义背景图或水印素材，可通过此接口修改已上传的图片。无需频繁修改图片素材的场景，建议直接在 [控制台 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769) 中操作。
 
         :param request: Request instance for ModifyPicture.
         :type request: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureRequest`
@@ -556,7 +483,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPicture", params)
+            headers = request.headers
+            body = self.call("ModifyPicture", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPictureResponse()
@@ -584,7 +512,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RemoveUser", params)
+            headers = request.headers
+            body = self.call("RemoveUser", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RemoveUserResponse()
@@ -612,7 +541,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RemoveUserByStrRoomId", params)
+            headers = request.headers
+            body = self.call("RemoveUserByStrRoomId", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RemoveUserByStrRoomIdResponse()
@@ -648,7 +578,10 @@ class TrtcClient(AbstractClient):
         - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置，最多支持2个画面。
         - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
 
-        注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
+        注意：
+        1、**混流转码为收费功能，调用接口将产生云端混流转码费用，详见[云端混流转码计费说明](https://cloud.tencent.com/document/product/647/49446)。**
+        2、2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
+        3、客户端混流和服务端混流不能混用。
 
         :param request: Request instance for StartMCUMixTranscode.
         :type request: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeRequest`
@@ -657,7 +590,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartMCUMixTranscode", params)
+            headers = request.headers
+            body = self.call("StartMCUMixTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartMCUMixTranscodeResponse()
@@ -693,7 +627,10 @@ class TrtcClient(AbstractClient):
         - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置。
         - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
 
-        注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
+        注意：
+        1、**混流转码为收费功能，调用接口将产生云端混流转码费用，详见[云端混流转码计费说明](https://cloud.tencent.com/document/product/647/49446)。**
+        2、2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
+        3、客户端混流和服务端混流不能混用。
 
         :param request: Request instance for StartMCUMixTranscodeByStrRoomId.
         :type request: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeByStrRoomIdRequest`
@@ -702,7 +639,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartMCUMixTranscodeByStrRoomId", params)
+            headers = request.headers
+            body = self.call("StartMCUMixTranscodeByStrRoomId", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartMCUMixTranscodeByStrRoomIdResponse()
@@ -730,7 +668,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopMCUMixTranscode", params)
+            headers = request.headers
+            body = self.call("StopMCUMixTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopMCUMixTranscodeResponse()
@@ -758,7 +697,8 @@ class TrtcClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopMCUMixTranscodeByStrRoomId", params)
+            headers = request.headers
+            body = self.call("StopMCUMixTranscodeByStrRoomId", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopMCUMixTranscodeByStrRoomIdResponse()
